pub enum ParameterConstraint {
Real,
Positive,
UnitInterval,
Bounded {
lower: f64,
upper: f64,
},
Simplex {
dim: usize,
},
LowerBounded {
lower: f64,
},
UpperBounded {
upper: f64,
},
}Expand description
Type of parameter constraint and its corresponding transformation
Variants
Real
Unconstrained real-valued parameter (identity transform)
Positive
Positive parameter (log transform: unconstrained -> positive)
UnitInterval
Parameter on (0, 1) (logistic transform)
Bounded
Parameter on (lower, upper) (scaled logistic transform)
Simplex
Simplex constraint (sum to 1) using stick-breaking transform
LowerBounded
Lower-bounded parameter (shifted log transform)
UpperBounded
Upper-bounded parameter (reflected log transform)
Implementations
Sourceimpl ParameterConstraint
impl ParameterConstraint
Sourcepub fn forward(&self, unconstrained: f64) -> f64
pub fn forward(&self, unconstrained: f64) -> f64
Transform from unconstrained to constrained space
Sourcepub fn inverse(&self, constrained: f64) -> Result<f64>
pub fn inverse(&self, constrained: f64) -> Result<f64>
Transform from constrained to unconstrained space
Sourcepub fn log_det_jacobian(&self, unconstrained: f64) -> f64
pub fn log_det_jacobian(&self, unconstrained: f64) -> f64
Compute the log absolute determinant of the Jacobian of the forward transform
This is needed for correcting the density when transforming from unconstrained to constrained space: p(constrained) = p_unconstrained(inverse(constrained)) * |det J^{-1}|
Equivalently, for the ELBO in unconstrained space: log p(forward(eta)) + log |det J_forward(eta)|