pub struct ARDBayesianRegression {
pub max_iter: usize,
pub tol: f64,
pub alpha_init: Option<Array1<f64>>,
pub beta_init: f64,
pub fit_intercept: bool,
}Expand description
Automatic Relevance Determination (ARD) Bayesian regression
ARD uses separate precision parameters for each feature to perform automatic feature selection by driving irrelevant features to zero.
Fields
max_iter: usizeMaximum number of iterations
tol: f64Convergence tolerance
alpha_init: Option<Array1<f64>>Initial alpha (precision) parameters
beta_init: f64Initial beta (noise precision) parameter
fit_intercept: boolWhether to fit intercept
Implementations
Sourceimpl ARDBayesianRegression
impl ARDBayesianRegression
Sourcepub fn with_max_iter(self, max_iter: usize) -> Self
pub fn with_max_iter(self, max_iter: usize) -> Self
Set maximum iterations
Sourcepub fn with_tolerance(self, tol: f64) -> Self
pub fn with_tolerance(self, tol: f64) -> Self
Set convergence tolerance
Sourcepub fn fit(
&self,
x: ArrayView2<'_, f64>,
y: ArrayView1<'_, f64>,
) -> StatsResult<ARDRegressionResult>
pub fn fit( &self, x: ArrayView2<'_, f64>, y: ArrayView1<'_, f64>, ) -> StatsResult<ARDRegressionResult>
Fit ARD Bayesian regression using iterative optimization