pub struct NoUTurnSampler {
pub initial_stepsize: f64,
pub max_tree_depth: usize,
pub target_acceptance: f64,
pub gamma: f64,
pub t0: f64,
pub kappa: f64,
pub seed: Option<u64>,
}Expand description
No-U-Turn Sampler (NUTS)
NUTS is an extension of HMC that automatically tunes the number of leapfrog steps by stopping when the trajectory starts to double back on itself.
Fields
initial_stepsize: f64Initial step size
max_tree_depth: usizeMaximum tree depth
target_acceptance: f64Target acceptance rate for step size adaptation
gamma: f64Step size adaptation parameter
t0: f64Step size adaptation parameter
kappa: f64Step size adaptation parameter
seed: Option<u64>Random seed
Implementations
Sourceimpl NoUTurnSampler
impl NoUTurnSampler
Sourcepub fn with_stepsize(self, stepsize: f64) -> Self
pub fn with_stepsize(self, stepsize: f64) -> Self
Set initial step size
Sourcepub fn with_max_depth(self, depth: usize) -> Self
pub fn with_max_depth(self, depth: usize) -> Self
Set maximum tree depth
Sourcepub fn sample<D: LogDensity>(
&self,
target: &D,
n_samples_: usize,
initial_state: ArrayView1<'_, f64>,
) -> Result<NUTSResult>
pub fn sample<D: LogDensity>( &self, target: &D, n_samples_: usize, initial_state: ArrayView1<'_, f64>, ) -> Result<NUTSResult>
Sample using NUTS algorithm