SviBayesianRegression

Struct SviBayesianRegression 

pub struct SviBayesianRegression {
    pub mean_beta: Array1<f64>,
    pub log_std_beta: Array1<f64>,
    pub shape_tau: f64,
    pub rate_tau: f64,
    pub prior_var: f64,
    pub prior_shape: f64,
    pub prior_rate: f64,
    pub n_features: usize,
    pub config: SviConfig,
}
SVI-specialized Bayesian linear regression

Uses stochastic variational inference to fit a Bayesian linear regression model, making it suitable for large datasets that don’t fit in memory.

Model: y = X * beta + epsilon, epsilon ~ N(0, sigma^2) Prior: beta ~ N(0, prior_var * I), sigma^2 ~ InvGamma(a, b)

Fields

mean_beta: Array1<f64>

Variational mean for coefficients

log_std_beta: Array1<f64>

Variational log std for coefficients

shape_tau: f64

Variational parameters for noise precision: shape and rate of Gamma

rate_tau: f64prior_var: f64

Prior variance for coefficients

prior_shape: f64

Prior shape for noise precision

prior_rate: f64

Prior rate for noise precision

n_features: usize

Number of features

config: SviConfig

SVI configuration

Implementations

Source

impl SviBayesianRegression

pub fn new(n_features: usize, config: SviConfig) -> Result<Self>

Create a new SVI Bayesian regression model

pub fn with_priors( self, prior_var: f64, prior_shape: f64, prior_rate: f64, ) -> Result<Self>

Set prior parameters

pub fn fit( &mut self, x: ArrayView2<'_, f64>, y: ArrayView1<'_, f64>, ) -> Result<SviRegressionResult>

Fit using SVI with mini-batches