pub struct EventStudy {
pub n_pre: usize,
pub n_post: usize,
}Expand description
Event-study design for estimating dynamic treatment effects.
Estimates the regression: y_{it} = Σ_{l≠-1} β_l D^l_{it} + α_i + δ_t + ε_{it} where D^l_{it} = 1 if unit i is treated and is l periods from its treatment date. The omitted period is l = -1 (normalisation).
Fields
n_pre: usizeHow many pre-treatment periods to include (>= 1)
n_post: usizeHow many post-treatment periods to include (>= 1)
Implementations
Sourceimpl EventStudy
impl EventStudy
Sourcepub fn estimate(
&self,
y: &ArrayView1<'_, f64>,
treated: &ArrayView1<'_, f64>,
n_units: usize,
n_periods: usize,
treat_period: usize,
) -> StatsResult<EventStudyResult>
pub fn estimate( &self, y: &ArrayView1<'_, f64>, treated: &ArrayView1<'_, f64>, n_units: usize, n_periods: usize, treat_period: usize, ) -> StatsResult<EventStudyResult>
Estimate dynamic treatment effects.
Arguments
y– outcome vector (n_units × n_periods, row-major)treated– binary indicator per unit (n_units,)n_units– number of unitsn_periods– number of time periodstreat_period– the first treatment period for all treated units (0-indexed)