pub struct PredictionSet {
pub lower: f64,
pub upper: f64,
pub set: Vec<usize>,
}Expand description
A prediction set for a single test point.
For regression tasks the set is the interval [lower, upper].
For classification tasks the set is a collection of class indices.
Fields
lower: f64Lower bound of the prediction interval (regression).
upper: f64Upper bound of the prediction interval (regression).
set: Vec<usize>Predicted class indices included in the set (classification).
Implementations
Sourceimpl PredictionSet
impl PredictionSet
Sourcepub fn classification(set: Vec<usize>) -> Self
pub fn classification(set: Vec<usize>) -> Self
Create a classification prediction set.
Sourcepub fn contains_value(&self, value: f64) -> bool
pub fn contains_value(&self, value: f64) -> bool
Return true if value is inside the regression interval.
Sourcepub fn contains_class(&self, class: usize) -> bool
pub fn contains_class(&self, class: usize) -> bool
Return true if class is in the classification set.