pub struct MultivariateNormalGibbs {
pub mean: Array1<f64>,
pub precision: Array2<f64>,
}Expand description
Multivariate normal Gibbs sampler
For sampling from a multivariate normal distribution where each variable given all others follows a normal distribution.
Fields
mean: Array1<f64>Mean vector
precision: Array2<f64>Precision matrix (inverse covariance)
Implementations