pub struct CanonicalCorrelationAnalysis {
pub n_components: Option<usize>,
pub scale: bool,
pub reg_param: f64,
pub max_iter: usize,
pub tol: f64,
}Expand description
Canonical Correlation Analysis
CCA finds linear combinations of variables in two datasets that have maximum correlation. This is useful for exploring relationships between two multivariate datasets.
Fields
n_components: Option<usize>Number of canonical components to compute
scale: boolWhether to scale the data
reg_param: f64Regularization parameter for numerical stability
max_iter: usizeMaximum number of iterations for iterative algorithms
tol: f64Convergence tolerance
Implementations
Sourceimpl CanonicalCorrelationAnalysis
impl CanonicalCorrelationAnalysis
Sourcepub fn with_n_components(self, ncomponents: usize) -> Self
pub fn with_n_components(self, ncomponents: usize) -> Self
Set number of components to compute
Sourcepub fn with_scale(self, scale: bool) -> Self
pub fn with_scale(self, scale: bool) -> Self
Set whether to scale the data
Sourcepub fn with_reg_param(self, regparam: f64) -> Self
pub fn with_reg_param(self, regparam: f64) -> Self
Set regularization parameter
Sourcepub fn with_max_iter(self, maxiter: usize) -> Self
pub fn with_max_iter(self, maxiter: usize) -> Self
Set maximum iterations
Sourcepub fn with_tolerance(self, tol: f64) -> Self
pub fn with_tolerance(self, tol: f64) -> Self
Set convergence tolerance
Sourcepub fn fit(
&self,
x: ArrayView2<'_, f64>,
y: ArrayView2<'_, f64>,
) -> Result<CCAResult>
pub fn fit( &self, x: ArrayView2<'_, f64>, y: ArrayView2<'_, f64>, ) -> Result<CCAResult>
Fit the CCA model
Sourcepub fn transform(
&self,
x: ArrayView2<'_, f64>,
y: ArrayView2<'_, f64>,
result: &CCAResult,
) -> Result<(Array2<f64>, Array2<f64>)>
pub fn transform( &self, x: ArrayView2<'_, f64>, y: ArrayView2<'_, f64>, result: &CCAResult, ) -> Result<(Array2<f64>, Array2<f64>)>
Transform new data using fitted CCA model
Sourcepub fn score(
&self,
x: ArrayView2<'_, f64>,
y: ArrayView2<'_, f64>,
result: &CCAResult,
) -> Result<Array1<f64>>
pub fn score( &self, x: ArrayView2<'_, f64>, y: ArrayView2<'_, f64>, result: &CCAResult, ) -> Result<Array1<f64>>
Compute canonical correlations for new data