LinearDiscriminantAnalysis

Struct LinearDiscriminantAnalysis 

pub struct LinearDiscriminantAnalysis {
    pub solver: LDASolver,
    pub shrinkage: Option<f64>,
    pub n_components: Option<usize>,
    pub priors: Option<Array1<f64>>,
    pub store_covariance: bool,
}
Linear Discriminant Analysis (LDA)

LDA is a dimensionality reduction technique that finds linear combinations of features that best separate different classes. It assumes that all classes have the same covariance structure.

Fields

solver: LDASolver

Solver type for eigenvalue decomposition

shrinkage: Option<f64>

Whether to shrink the covariance estimate

n_components: Option<usize>

Number of components to keep (None = automatic)

priors: Option<Array1<f64>>

Prior probabilities for each class (None = empirical)

store_covariance: bool

Store training fit results

Implementations

Source

impl LinearDiscriminantAnalysis

pub fn new() -> Self

Create a new LDA instance

pub fn with_solver(self, solver: LDASolver) -> Self

Set the solver type

pub fn with_shrinkage(self, shrinkage: f64) -> Self

Set shrinkage parameter for covariance regularization

pub fn with_n_components(self, n_components: usize) -> Self

Set number of components to keep

pub fn with_priors(self, priors: Array1<f64>) -> Self

Set prior probabilities

pub fn with_store_covariance(self, store: bool) -> Self

Set whether to store covariance matrix

pub fn fit( &self, x: ArrayView2<'_, f64>, y: ArrayView1<'_, i32>, ) -> Result<LDAResult>

Fit the LDA model

pub fn transform( &self, x: ArrayView2<'_, f64>, result: &LDAResult, ) -> Result<Array2<f64>>

Transform data to discriminant space

pub fn predict( &self, x: ArrayView2<'_, f64>, result: &LDAResult, ) -> Result<Array1<i32>>

Predict class labels

pub fn decision_function( &self, x: ArrayView2<'_, f64>, result: &LDAResult, ) -> Result<Array2<f64>>

Compute decision function scores

pub fn predict_proba( &self, x: ArrayView2<'_, f64>, result: &LDAResult, ) -> Result<Array2<f64>>

Compute prediction probabilities using softmax