pub struct NestedFrailtyModel { /* private fields */ }Expand description
Two-level nested frailty model.
The hazard for subject k in inner cluster j within outer cluster i is: h(t | x, v_i, w_ij) = v_i · w_ij · h₀(t) · exp(x β)
Fitted via a nested EM algorithm that alternates between updating outer frailties, inner frailties, regression coefficients, and variance components.
Implementations
Sourceimpl NestedFrailtyModel
impl NestedFrailtyModel
Sourcepub fn new(config: FrailtyConfig) -> Self
pub fn new(config: FrailtyConfig) -> Self
Create a new nested frailty model with the given configuration.
Sourcepub fn fit(
&self,
times: &[f64],
events: &[bool],
covariates: &[&[f64]],
inner_clusters: &[usize],
outer_clusters: &[usize],
) -> StatsResult<NestedFrailtyResult>
pub fn fit( &self, times: &[f64], events: &[bool], covariates: &[&[f64]], inner_clusters: &[usize], outer_clusters: &[usize], ) -> StatsResult<NestedFrailtyResult>
Fit the nested frailty model.
Arguments
times– observed event/censoring times (n elements)events– event indicatorscovariates– covariate matrix (n rows)inner_clusters– inner cluster assignment for each subject (e.g., center)outer_clusters– outer cluster assignment for each subject (e.g., region)
Errors
Returns StatsError on dimension mismatch, insufficient clusters, etc.