pub enum FlowLayer {
Planar {
w: Array1<f64>,
u: Array1<f64>,
b: f64,
},
Radial {
z0: Array1<f64>,
alpha: f64,
beta: f64,
},
}Expand description
Type of normalizing flow layer
Variants
Planar
Planar flow: f(z) = z + u * tanh(w^T z + b)
Radial
Radial flow: f(z) = z + beta * (z - z0) / (alpha + ||z - z0||)
Implementations
Sourceimpl FlowLayer
impl FlowLayer
Sourcepub fn new_planar(dim: usize, seed: u64) -> Self
pub fn new_planar(dim: usize, seed: u64) -> Self
Create a new planar flow layer with random initialization
Sourcepub fn new_radial(dim: usize, seed: u64) -> Self
pub fn new_radial(dim: usize, seed: u64) -> Self
Create a new radial flow layer with random initialization
Sourcepub fn forward(&self, z: &Array1<f64>) -> StatsResult<(Array1<f64>, f64)>
pub fn forward(&self, z: &Array1<f64>) -> StatsResult<(Array1<f64>, f64)>
Apply the flow transformation: f(z) and compute log|det(df/dz)|
Returns (f(z), log|det J|)
Sourcepub fn get_params(&self) -> Array1<f64>
pub fn get_params(&self) -> Array1<f64>
Get all parameters as a flat vector
Sourcepub fn set_params(&mut self, params: &Array1<f64>) -> StatsResult<()>
pub fn set_params(&mut self, params: &Array1<f64>) -> StatsResult<()>
Set parameters from a flat vector