pub struct FlowVi {
pub config: FlowViConfig,
}Expand description
Flow-enhanced Variational Inference
Uses a normalizing flow on top of a mean-field Gaussian base distribution to produce a more flexible posterior approximation.
The ELBO becomes:
ELBO = E_{z_0 ~ q_0} [log p(x, z_K) - log q_0(z_0) + sum_k log|det J_k|]where z_K = f_K . … . f_1(z_0) and q_0 = N(mu, diag(sigma^2)).
Fields
config: FlowViConfigConfiguration
Implementations