pub struct SviBayesianRegression {
pub mean_beta: Array1<f64>,
pub log_std_beta: Array1<f64>,
pub shape_tau: f64,
pub rate_tau: f64,
pub prior_var: f64,
pub prior_shape: f64,
pub prior_rate: f64,
pub n_features: usize,
pub config: SviConfig,
}Expand description
SVI-specialized Bayesian linear regression
Uses stochastic variational inference to fit a Bayesian linear regression model, making it suitable for large datasets that don’t fit in memory.
Model: y = X * beta + epsilon, epsilon ~ N(0, sigma^2) Prior: beta ~ N(0, prior_var * I), sigma^2 ~ InvGamma(a, b)
Fields
mean_beta: Array1<f64>Variational mean for coefficients
log_std_beta: Array1<f64>Variational log std for coefficients
shape_tau: f64Variational parameters for noise precision: shape and rate of Gamma
rate_tau: f64prior_var: f64Prior variance for coefficients
prior_shape: f64Prior shape for noise precision
prior_rate: f64Prior rate for noise precision
n_features: usizeNumber of features
config: SviConfigSVI configuration
Implementations
Sourceimpl SviBayesianRegression
impl SviBayesianRegression
Sourcepub fn new(n_features: usize, config: SviConfig) -> Result<Self>
pub fn new(n_features: usize, config: SviConfig) -> Result<Self>
Create a new SVI Bayesian regression model
Sourcepub fn with_priors(
self,
prior_var: f64,
prior_shape: f64,
prior_rate: f64,
) -> Result<Self>
pub fn with_priors( self, prior_var: f64, prior_shape: f64, prior_rate: f64, ) -> Result<Self>
Set prior parameters
Sourcepub fn fit(
&mut self,
x: ArrayView2<'_, f64>,
y: ArrayView1<'_, f64>,
) -> Result<SviRegressionResult>
pub fn fit( &mut self, x: ArrayView2<'_, f64>, y: ArrayView1<'_, f64>, ) -> Result<SviRegressionResult>
Fit using SVI with mini-batches