pub fn parallel_quantile(data: &[f64], q: f64) -> StatsResult<f64>Expand description
Compute a single quantile using parallel sort.
For large arrays this is faster than a sequential sort because the merge phase can be overlapped with computation.
Arguments
data- Input data (will be sorted internally)q- Quantile in [0, 1]