pub struct StructuralTimeSeries;Expand description
Structural Time Series builder and fitter.
Implementations
Sourceimpl StructuralTimeSeries
impl StructuralTimeSeries
Sourcepub fn fit_local_level(
y: &[f64],
level_var: f64,
obs_var: f64,
init_level: Option<f64>,
init_var: Option<f64>,
) -> StatsResult<StsFitResult>
pub fn fit_local_level( y: &[f64], level_var: f64, obs_var: f64, init_level: Option<f64>, init_var: Option<f64>, ) -> StatsResult<StsFitResult>
Fit a local level model to a univariate time series.
The local level model is:
y_t = μ_t + ε_t, ε_t ~ N(0, σ²_ε)
μ_{t+1} = μ_t + η_t, η_t ~ N(0, σ²_η)State x_t = [μ_t].
Arguments
y– univariate time series (length T).level_var– process noise variance σ²_η (must be > 0).obs_var– observation noise variance σ²_ε (must be > 0).init_level– initial level estimate (defaults toy[0]).init_var– initial state variance (defaults to 1e6 for diffuse init).
Sourcepub fn fit_local_linear_trend(
y: &[f64],
level_var: f64,
slope_var: f64,
obs_var: f64,
init_level: Option<f64>,
init_slope: Option<f64>,
init_var: Option<f64>,
) -> StatsResult<StsFitResult>
pub fn fit_local_linear_trend( y: &[f64], level_var: f64, slope_var: f64, obs_var: f64, init_level: Option<f64>, init_slope: Option<f64>, init_var: Option<f64>, ) -> StatsResult<StsFitResult>
Fit a local linear trend model to a univariate time series.
The local linear trend model is:
y_t = μ_t + ε_t, ε_t ~ N(0, σ²_ε)
μ_{t+1} = μ_t + ν_t + η_t, η_t ~ N(0, σ²_η)
ν_{t+1} = ν_t + ζ_t, ζ_t ~ N(0, σ²_ζ)State x_t = [μ_t, ν_t].
Arguments
y– univariate time series.level_var– level innovation variance σ²_η.slope_var– slope innovation variance σ²_ζ.obs_var– observation noise variance σ²_ε.init_level– initial level (defaults toy[0]).init_slope– initial slope (defaults to 0).init_var– initial state variance (defaults to 1e6).